@@ -1,5 +1,4 @@
-use crate::export::Principal;
-use crate::RequestId;
+use crate::{export::Principal, RequestId};
 
 use serde::{Deserialize, Serialize};
 
